import {SimpleTreeView, TreeItem} from "@mui/x-tree-view";
import React from "react";


interface ExperimentParameters {
    id: number;
    run_number: number;
    beamline_parameters: {
        synchrotron: string;
        beamline: string;
        detector: {
            manufacturer: string;
            model: string;
            type: string;
            serial_number: string;
            detector_distance_mm: number;
            beam_center_x_px: number;
            beam_center_y_px: number;
            pixel_size_x_um: number;
            pixel_size_y_um: number;
            number_of_images: number;
            exposure_time_s: number;
        };
        // Add additional fields if needed.
    };
}

<SimpleTreeView
    defaultCollapseIcon="▾"
    defaultExpandIcon="▸"
    sx={{ fontSize: '0.875rem' }}
>
    <TreeItem nodeId="detector-group" label={<strong>Detector Details</strong>}>
        <TreeItem nodeId="detector-group" label={<strong>Detector Details</strong>}>
            <TreeItem
                nodeId="detector-manufacturer"
                label={`Manufacturer: ${detector?.manufacturer || 'N/A'}`}
            />
            <TreeItem
                nodeId="detector-model"
                label={`Model: ${detector?.model || 'N/A'}`}
            />
            <TreeItem
                nodeId="detector-type"
                label={`Type: ${detector?.type || 'N/A'}`}
            />
            <TreeItem
                nodeId="detector-serial"
                label={`Serial Number: ${detector?.serial_number || 'N/A'}`}
            />
            <TreeItem
                nodeId="detector-distance"
                label={`Distance (mm): ${detector?.detector_distance_mm ?? 'N/A'}`}
            />
            <TreeItem
                nodeId="beam-center"
                label={
                    detector
                        ? `Beam Center: x:${detector.beam_center_x_px}, y:${detector.beam_center_y_px}`
                        : 'Beam Center: N/A'
                }
            />
            <TreeItem
                nodeId="pixel-size"
                label={
                    detector
                        ? `Pixel Size (µm): x:${detector.pixel_size_x_um}, y:${detector.pixel_size_y_um}`
                        : 'Pixel Size: N/A'
                }
            />
            <TreeItem
                nodeId="img-count"
                label={`Number of Images: ${detector?.number_of_images ?? 'N/A'}`}
            />
            <TreeItem
                nodeId="exposure-time"
                label={`Exposure Time (s): ${detector?.exposure_time_s ?? 'N/A'}`}
            />
        </TreeItem>



    </TreeItem>
</SimpleTreeView>